@@ -51,6 +51,7 @@ from ._jsii import *
 
 __all__ = [
     "nx_monorepo",
+    "pdk_nag",
     "pipeline",
 ]
 
@@ -58,4 +59,5 @@ publication.publish()
 
 # Loading modules to ensure their types are registered with the jsii runtime library
 from . import nx_monorepo
+from . import pdk_nag
 from . import pipeline
