@@ -9,16 +9,18 @@ const stack = new Stack(app, 'MyStack');
 ...
 ```
 
-As shown above, this will configure your application to have CDKNag run on synthesis and by default will cause the build to fail if errors are encountered.
+As shown above, this will configure your application to have CDKNag run on synthesis.
 
-Additional configuration can be passed in to relax these errors if needed as follows:
+By default, CDK will trigger a failure on `synth` if any errors are encountered. To relax these, run the following:
 
-```python
-const app = PDKNag.app({ failOnError: false });
-const stack = new Stack(app, 'MyStack');
+```shell
+cdk synth --ignore-errors
+```
 
-const nagResults: NagResult[] = app.nagResults(); // Do something with the results if needed
-...
+Conversely, CDK will not fail on synth if warnings are detected. To enforce that all warnings are resolved, run the following command:
+
+```shell
+cdk synth --strict
 ```
 '''
 import abc
@@ -177,7 +179,7 @@ class PDKNag(metaclass=jsii.JSIIMeta, jsii_type="aws-prototyping-sdk.pdk_nag.PDK
     ) -> "PDKNagApp":
         '''Returns an instance of an App with Nag enabled.
 
-        :param fail_on_error: Determines whether any errors encountered should trigger a test failure. Default: true
+        :param fail_on_error: Determines whether any errors encountered should trigger a test failure. Default: false
         :param fail_on_warning: Determines whether any warnings encountered should trigger a test failure. Default: false
         :param analytics_reporting: Include runtime versioning information in the Stacks of this app. Default: Value of 'aws:cdk:version-reporting' context key
         :param auto_synth: Automatically call ``synth()`` before the program exits. If you set this, you don't have to call ``synth()`` explicitly. Note that this feature is only available for certain programming languages, and calling ``synth()`` is still recommended. Default: true if running via CDK CLI (``CDK_OUTDIR`` is set), ``false`` otherwise
@@ -260,7 +262,7 @@ class PDKNagApp(
         tree_metadata: typing.Optional[builtins.bool] = None,
     ) -> None:
         '''
-        :param fail_on_error: Determines whether any errors encountered should trigger a test failure. Default: true
+        :param fail_on_error: Determines whether any errors encountered should trigger a test failure. Default: false
         :param fail_on_warning: Determines whether any warnings encountered should trigger a test failure. Default: false
         :param analytics_reporting: Include runtime versioning information in the Stacks of this app. Default: Value of 'aws:cdk:version-reporting' context key
         :param auto_synth: Automatically call ``synth()`` before the program exits. If you set this, you don't have to call ``synth()`` explicitly. Note that this feature is only available for certain programming languages, and calling ``synth()`` is still recommended. Default: true if running via CDK CLI (``CDK_OUTDIR`` is set), ``false`` otherwise
@@ -365,7 +367,7 @@ class PDKNagAppProps(aws_cdk.AppProps):
         :param outdir: The output directory into which to emit synthesized artifacts. You should never need to set this value. By default, the value you pass to the CLI's ``--output`` flag will be used, and if you change it to a different directory the CLI will fail to pick up the generated Cloud Assembly. This property is intended for internal and testing use. Default: - If this value is *not* set, considers the environment variable ``CDK_OUTDIR``. If ``CDK_OUTDIR`` is not defined, uses a temp directory.
         :param stack_traces: Include construct creation stack trace in the ``aws:cdk:trace`` metadata key of all constructs. Default: true stack traces are included unless ``aws:cdk:disable-stack-trace`` is set in the context.
         :param tree_metadata: Include construct tree metadata as part of the Cloud Assembly. Default: true
-        :param fail_on_error: Determines whether any errors encountered should trigger a test failure. Default: true
+        :param fail_on_error: Determines whether any errors encountered should trigger a test failure. Default: false
         :param fail_on_warning: Determines whether any warnings encountered should trigger a test failure. Default: false
 
         :inheritDoc: true
@@ -466,7 +468,7 @@ class PDKNagAppProps(aws_cdk.AppProps):
     def fail_on_error(self) -> typing.Optional[builtins.bool]:
         '''Determines whether any errors encountered should trigger a test failure.
 
-        :default: true
+        :default: false
         '''
         result = self._values.get("fail_on_error")
         return typing.cast(typing.Optional[builtins.bool], result)
